@@ -136,7 +136,7 @@ def get_dep_symptoms_dict():
                        'thiếu cân', 'ốm', 'tăng cân', 'suy dinh dưỡng']
     d['hô hấp'] = ['khó thở', 'đau ngực', 'sốt', 'nôn', 'ho']
     d['nội thận'] = ['mệt', 'tiểu đêm', 'đái đêm', 'tăng huyết áp',
-                     'đái tháo đường', 'tiểu đường', 'phù', 'ói', 'nôn', 'khó thở', 'mệt', 'lơ mơ', ]
+                     'đái tháo đường', 'tiểu đường', 'phù, ói', 'nôn', 'khó thở', 'mệt', 'lơ mơ', ]
     d['nhi'] = ['sốt', 'ho', 'ói', 'nôn', 'táo bón', 'sổ mũi', 'tiêu chảy', 'đau bụng', 'nôn ói'
                 'dị ứng', 'nhiễm trùng da', 'tai nạn', 'co giật', 'thở mệt', 'ọc sữa', 'ho',
                 'đau đầu', 'dị ứng', 'viêm da', 'thở khò khè', ]
@@ -169,3 +169,10 @@ def get_dep_symptoms_dict():
                          'khàn tiếng', 'viêm họng', 'viêm xoang', ]
 
     return d
+
+def get_list_of_symps(path="vi_nlp_core/utils/symptoms.txt"):
+    data = []
+    with open(path,'r',encoding='utf-8') as f:
+        for line in f:
+            data.append(line.replace('\n',''))
+    return data 
\ No newline at end of file
